.. _orion.primitives:

orion.primitives
================

.. currentmodule:: orion.primitives

Primitives
~~~~~~~~~~

.. autosummary::
   :toctree: api/

   orion.primitives.tadgan.TadGAN
   orion.primitives.tadgan.score_anomalies
   orion.primitives.timeseries_preprocessing.fillna
   orion.primitives.timeseries_errors.regression_errors
   orion.primitives.timeseries_errors.reconstruction_errors
   orion.primitives.timeseries_anomalies.find_anomalies
   orion.primitives.azure_anomaly_detector.split_sequence
   orion.primitives.azure_anomaly_detector.detect_anomalies
